/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef DMT_OMEGA_MOVIE_HH
#define DMT_OMEGA_MOVIE_HH

#include "DatEnv.hh"
#include "Omega_c/wtile.hh"
#include "Omega_c/wresample.hh"
#include "Omega_c/wfigure.hh"
#include "OperStateCondList.hh"
#include "Time.hh"
#include <string>

/** wmovie plots omega-transform plots in real time
 */
class wmovie : public DatEnv {
public:
   wmovie(int argc, const char* argv[]);
   ~wmovie(void);
   void configure(std::string& file);
   void setup(double rate);
   void ProcessData(void);
public:
   struct movie_frame {
      Time        _gps_time;
      int         _nGlitch;
      std::string _html_path;
      std::string _thumb_path;
   };
   typedef std::vector<movie_frame> frame_vect;
private:
   std::string        _channel;  ///< channel to be watched/plotted
   Interval           _flush;    ///< Filter settling time.
   Interval           _stride;   ///< plotting stride.
   Interval           _tWindow;  ///< Time window searched for glitches
   wpipe::dble_vect   _qRange;   ///< Q range
   wpipe::dble_vect   _fRange;   ///< Frequency range
   std::string        _outputDirectory;
   wpipe::wtile       _tiling;
   double             _fSample;
   int                _maxglitch;
   double             _glitch_threshold;
   double             _dtinflation;
   double             _bwinflation;
   int                _debug;
   OperStateCondList  _oscList;
   std::string        _oscCondition;
   int                _max_frames;

   //------------------------------------  State data
   Time               _current;
   wpipe::resampler   _resampler;
   wpipe::tser_vect   _data;               // resampled TSeries in _data[0]
   //wpipe::wcondition _conditioner;
   //GDSPlot           _plot;
   wpipe::wfigure     _figureHandle;
   frame_vect         _movie;
};
#endif  // !defined(DMT_OMEGA_MOVIE_HH)
